@@ -13,7 +13,7 @@ from feeluown.models import (
 )
 from feeluown.player import (
     PlaybackMode, Playlist, LiveLyric,
-    FM, Player, RecentlyPlayed
+    FM, Player, RecentlyPlayed, PlayerPositionDelegate
 )
 from feeluown.plugin import PluginsManager
 from feeluown.version import VersionManager
@@ -35,12 +35,15 @@ class App:
     GuiMode = AppMode.gui.value
     CliMode = AppMode.cli.value
 
-    def __init__(self, args, config):
-
+    def __init__(self, args, config, **kwargs):
+        App._instance = self
         self.mode = config.MODE  # DEPRECATED: use app.config.MODE instead
         self.config = config
         self.args = args
         self.initialized = Signal()
+        # .. versionadded:: 3.8.11
+        #    App started signal. Maybe the initialized signal can be removed?
+        self.started = Signal()  # App is ready to use, for example, UI is available.
         self.about_to_shutdown = Signal()
 
         self.plugin_mgr = PluginsManager(self)
@@ -52,9 +55,16 @@ class App:
         self.library = Library(config.PROVIDERS_STANDBY)
         # TODO: initialization should be moved into initialize
         Resolver.library = self.library
-
         # Player.
         self.player = Player(audio_device=bytes(config.MPV_AUDIO_DEVICE, 'utf-8'))
+        # Theoretically, each caller maintain its own position delegate.
+        # For simplicity, this delegate is created for common use cases and
+        #
+        # For progress slider and label in player bar, user may only see the difference
+        # when it is greater than 1s. There are usually only one or two lines of lyrics
+        # in one second. Considering the use cases and performance, I guess 300ms is
+        # a reasonable interval.
+        self.player_pos_per300ms = PlayerPositionDelegate(self.player, interval=300)
         self.playlist = Playlist(self, audio_select_policy=config.AUDIO_SELECT_POLICY)
         self.live_lyric = LiveLyric(self)
         self.fm = FM(self)
@@ -63,10 +73,11 @@ class App:
         # TODO: initialization should be moved into initialize
         self.player.set_playlist(self.playlist)
 
-        self.about_to_shutdown.connect(lambda _: self.dump_state(), weak=False)
+        self.about_to_shutdown.connect(lambda _: self.dump_and_save_state(), weak=False)
 
     def initialize(self):
-        self.player.position_changed.connect(self.live_lyric.on_position_changed)
+        self.player_pos_per300ms.initialize()
+        self.player_pos_per300ms.changed.connect(self.live_lyric.on_position_changed)
         self.playlist.song_changed.connect(self.live_lyric.on_song_changed,
                                            aioqueue=True)
         self.plugin_mgr.scan()
@@ -74,14 +85,6 @@ class App:
     def run(self):
         pass
 
-    @property
-    def instance(self) -> Optional['App']:
-        """App running instance.
-
-        .. versionadded:: 3.8
-        """
-        return App._instance
-
     @property
     def has_server(self) -> bool:
         """
@@ -104,19 +107,12 @@ class App:
     def get_listen_addr(self):
         return '0.0.0.0' if self.config.ALLOW_LAN_CONNECT else '127.0.0.1'
 
-    def load_state(self):
+    def apply_state(self, state):
         playlist = self.playlist
         player = self.player
         recently_played = self.recently_played
 
-        try:
-            with open(STATE_FILE, 'r', encoding='utf-8') as f:
-                state = json.load(f)
-        except FileNotFoundError:
-            pass
-        except json.decoder.JSONDecodeError:
-            logger.exception('invalid state file')
-        else:
+        if state:
             player.volume = state['volume']
 
             # Restore recently_played states.
@@ -165,8 +161,22 @@ class App:
                     player.set_play_range(start=state['position'])
                     playlist.set_current_song(song)
 
+    def load_state(self):
+        try:
+            with open(STATE_FILE, 'r', encoding='utf-8') as f:
+                state = json.load(f)
+        except FileNotFoundError:
+            return {}
+        except json.decoder.JSONDecodeError:
+            logger.exception('invalid state file')
+            return {}
+        return state
+
+    def load_and_apply_state(self):
+        state = self.load_state()
+        self.apply_state(state)
+
     def dump_state(self):
-        logger.info("Dump app state")
         playlist = self.playlist
         player = self.player
         recently_played = self.recently_played
@@ -185,6 +195,11 @@ class App:
             'recently_played': [reverse(song, as_line=True)
                                 for song in recently_played.list_songs()]
         }
+        return state
+
+    def dump_and_save_state(self):
+        logger.info("Dump and save app state")
+        state = self.dump_state()
         with open(STATE_FILE, 'w', encoding='utf-8') as f:
             json.dump(state, f)
 
@@ -223,11 +238,12 @@ class App:
         logger.info('Do graceful shutdown')
         try:
             self.about_to_shutdown.emit(self)
+            self.player_pos_per300ms.stop()
             self.player.stop()
             self.exit_player()
         except:  # noqa, pylint: disable=bare-except
             logger.exception("about-to-exit failed")
-        logger.info('Ready for shutdown')
+        logger.info('Ready for shutdown, or crash :)')
 
     def exit_player(self):
         self.player.shutdown()  # this cause 'abort trap' on macOS
@@ -236,6 +252,13 @@ class App:
         self.about_to_exit()
 
 
+def get_app() -> Optional['App']:
+    """
+    .. versionadded:: 3.8.11
+    """
+    return App._instance
+
+
 def create_app(args, config) -> App:
     """App factory function.
 
