@@ -9,7 +9,8 @@ HERE = pathlib.Path(__file__).resolve()
 ICONS_DIR = HERE.parent.parent / 'gui' / 'assets' / 'icons'
 
 mac_shell_str = """#!/bin/bash
-/usr/local/bin/feeluown --log-to-file
+export PATH=$PATH:/usr/local/bin/:/opt/homebrew/bin/
+feeluown --log-to-file
 """
 
 mac_plist_str = """<?xml version="1.0" encoding="UTF-8"?>
@@ -110,7 +111,7 @@ def gen_for_win32():
     #   will tell user it has no priviledge to run this program
     pyexe = os.path.join(os.path.dirname(sys.executable), 'pythonw')
     command = '{} -m feeluown'.format(pyexe)
-    ico = HERE.parent.parent / 'icons' / 'feeluown.ico'
+    ico = HERE.parent.parent / 'gui' / 'assets' / 'icons' / 'feeluown.ico'
     name = 'FeelUOwn'
     make_shortcut(command, name=name, icon=str(ico), terminal=False)
 
