@@ -1,25 +1,34 @@
 import argparse
 import asyncio
 import logging
+import os
 import signal
 import sys
 import warnings
 
 from feeluown.app import AppMode, create_app, create_config
-from feeluown.utils.utils import is_port_inuse
+from feeluown.utils.utils import is_port_inuse, win32_is_port_binded
 from feeluown.fuoexec import fuoexec_load_rcfile, fuoexec_init
 from feeluown.utils import aio
 from feeluown.utils.dispatch import Signal  # noqa: E402
 
 from .base import ensure_dirs, setup_config, setup_logger  # noqa: E402
 
-
 logger = logging.getLogger(__name__)
 
 
 def run_app(args: argparse.Namespace):
     args, config = before_start_app(args)
-    aio.run(start_app(args, config))
+    # FIXME: qasync does not work with 'python3.11'.
+    # https://github.com/CabbageDevelopment/qasync/issues/68
+    if sys.version_info.major == 3 and sys.version_info.minor >= 11:
+        runner = asyncio.runners.Runner()
+        try:
+            runner.run(start_app(args, config))
+        finally:
+            runner.close()
+    else:
+        aio.run(start_app(args, config))
 
 
 def before_start_app(args):
@@ -58,6 +67,13 @@ def before_start_app(args):
     # Run.
     #
     if AppMode.gui in AppMode(config.MODE):
+        if sys.platform == 'win32':
+            # Enable auto scale by default so that it can work well with HiDPI display.
+            os.environ.setdefault('QT_AUTO_SCREEN_SCALE_FACTOR', '1')
+        elif sys.platform == 'darwin':
+            # Use native event loop on macOS, so that some native service such as
+            # nowplaying can work.
+            os.environ.setdefault('QT_EVENT_DISPATCHER_CORE_FOUNDATION', '1')
         try:
             # HELP: QtWebEngineWidgets must be imported before a
             #   QCoreApplication instance is created.
@@ -76,6 +92,7 @@ async def start_app(args, config, sentinal=None):
     """
     Signal.setup_aio_support()
 
+    # create_app takes about 300ms.
     app = create_app(args, config)
 
     # Do fuoexec initialization before app initialization.
@@ -86,10 +103,8 @@ async def start_app(args, config, sentinal=None):
     # all objects can do initialization here. some objects may emit signal,
     # some objects may connect with others signals.
     app.initialize()
-    app.initialized.emit(app)
 
-    # Load last state.
-    app.load_state()
+    app.initialized.emit(app)
 
     def sighanlder(signum, _):
         logger.info('Signal %d is received', signum)
@@ -111,6 +126,9 @@ async def start_app(args, config, sentinal=None):
 
     app.about_to_shutdown.connect(shutdown, weak=False)
 
+    # GUI state must be load before running app, otherwise, it does not take effects.
+    app.load_and_apply_state()
+
     # App can exit in several ways.
     #
     # GUI mode:
@@ -123,6 +141,8 @@ async def start_app(args, config, sentinal=None):
     # 1. Ctrl-C
     # 2. SIGTERM
     app.run()
+    app.started.emit(app)
+
     await sentinal
 
     Signal.teardown_aio_support()
@@ -147,8 +167,14 @@ def precheck(args, config):
 
     # Check if ports are in use.
     if AppMode.server in AppMode(config.MODE):
-        if is_port_inuse(config.RPC_PORT) or \
-           is_port_inuse(config.PUBSUB_PORT):
+        if sys.platform == 'win32':
+            host = '0.0.0.0' if config.ALLOW_LAN_CONNECT else '127.0.0.1'
+            used = win32_is_port_binded(host, config.RPC_PORT) or \
+                win32_is_port_binded(host, config.PUBSUB_PORT)
+        else:
+            # Maybe use the same checking method as windows on other platforms.
+            used = is_port_inuse(config.RPC_PORT) or is_port_inuse(config.PUBSUB_PORT)
+        if used:
             err_msg = (
                 'App fails to start services because '
                 f'either port {config.RPC_PORT} or {config.PUBSUB_PORT} '
