@@ -1,30 +1,52 @@
-"""
-feeluown.gui.helpers
-~~~~~~~~~~~~~~~~
+# mypy: disable-error-code=attr-defined
+#
+# HELP: Disable mypy check(attr-defined) since there is no good way to
+# typing a Mixin class like ItemViewNoScroll: https://github.com/python/typing/issues/213
+#
+# TODO(cosven): Such mixin class(like ItemViewNoScrollMixin) has little reable and
+# it's hard to typing. I think we can split it into a delegate and a mixin to solve
+# this problem.
+#
+# For example::
+#
+#     class ItemViewNoScrollManager: ...
+#     class ItemViewNoScrollMixin: ...
+#     class ListView(ItemViewNoScrollMixin, QListView):
+#         def __init__(self):
+#             self.no_scroll_manager = ItemViewNoScrollManager(self)
+#     class NoScrollableItemView(Protocol):
+#         no_scroll_manager: ItemViewNoScrollManager
 
-和应用逻辑相关的一些工具函数
-"""
+from __future__ import annotations
 import asyncio
-import itertools
 import random
 import sys
 import logging
+from typing import TypeVar, List, Optional, Generic, Union, cast, TYPE_CHECKING
 
 try:
     # helper module should work in no-window mode
     from PyQt5.QtCore import QModelIndex, QSize, Qt, pyqtSignal, QSortFilterProxyModel, \
         QAbstractListModel
     from PyQt5.QtGui import QPalette, QFontMetrics
-    from PyQt5.QtWidgets import QApplication, QScrollArea
+    from PyQt5.QtWidgets import QApplication, QScrollArea, QWidget
 except ImportError:
     pass
 
 from feeluown.utils import aio
-from feeluown.excs import ProviderIOError
+from feeluown.utils.reader import AsyncReader, Reader
+from feeluown.utils.typing_ import Protocol
+from feeluown.excs import ProviderIOError, ResourceNotFound
 from feeluown.library import NotSupported, ModelType, BaseModel
 from feeluown.models.uri import reverse
 
+
+if TYPE_CHECKING:
+    from feeluown.app.gui_app import GuiApp
+
+
 logger = logging.getLogger(__name__)
+T = TypeVar("T")
 
 
 async def async_run(func, loop=None, executor=None):
@@ -41,6 +63,10 @@ class ActionError(Exception):
     pass
 
 
+def get_qapp() -> QApplication:
+    return cast(QApplication, QApplication.instance())
+
+
 def is_macos():
     """Check if operating system is macOS
 
@@ -79,7 +105,7 @@ def palette_set_bg_color(palette, color):
 
 
 class BgTransparentMixin:
-    def __init__(self, *args, **kwargs):
+    def __init__(self: QWidget, *args, **kwargs):  # type: ignore[misc]
         palette = self.palette()
         palette_set_bg_color(palette, Qt.transparent)
         self.setPalette(palette)
@@ -144,6 +170,14 @@ class ItemViewNoScrollMixin:
     automatically adjueted.
 
     The itemview with no_scroll_v=True is usually used with an outside ScrollArea.
+
+    Python Notes::
+
+        ItemViewNoScrollMixin follows the "cooperative multi-inheritance" pattern.
+        Since ItemViewNoScrollMixin use some QObject API, subclass should consider
+        the MRO order. In other words, ItemViewNoScrollMixin should be the parent
+        class of QObject. XWidget(ItemViewNoScrollMixin, QObject) is a good choice,
+        and XWidget(QObject, ItemViewNoScrollMixin) is not.
     """
     def __init__(self, *args, no_scroll_v=True, row_height=0, least_row_count=0,
                  fixed_row_count=0, reserved=30, **kwargs):
@@ -157,6 +191,7 @@ class ItemViewNoScrollMixin:
         .. versionadded:: 3.8.9
            The *fixed_row_count* parameter was added.
         """
+        super().__init__(**kwargs)  # Cooperative multi-inheritance.
         self._least_row_count = least_row_count
         self._fixed_row_count = fixed_row_count
         self._row_height = row_height
@@ -210,7 +245,7 @@ class ItemViewNoScrollMixin:
             self.adjust_height()
 
     def setModel(self, model):
-        super().setModel(model)
+        super().setModel(model)  # type: ignore[misc]
         if model is None:
             return
         model.rowsInserted.connect(self.on_rows_changed)
@@ -228,10 +263,10 @@ class ItemViewNoScrollMixin:
             else:
                 e.ignore()  # let parents handle it
         else:
-            super().wheelEvent(e)
+            super().wheelEvent(e)  # type: ignore[misc]
 
     def sizeHint(self):
-        super_size_hint = super().sizeHint()
+        super_size_hint = super().sizeHint()  # type: ignore[misc]
         if self._no_scroll_v is False:
             return super_size_hint
 
@@ -312,7 +347,27 @@ class Paddings(tuple):
 Margins = Paddings
 
 
-class ReaderFetchMoreMixin:
+# HELP(cosven): please help remove duplicate code between ReaderFetchMoreMixin
+# and this class.
+class ModelUsingReader(Protocol[T]):
+    _reader: Union[Reader[T], AsyncReader]
+    _items: List[T]
+    _fetch_more_step: int
+    _is_fetching: bool
+
+    def rowCount(self) -> int: ...
+    def beginInsertRows(self, _, __, ___): ...
+    def endInsertRows(self): ...
+    def canFetchMore(self, _) -> bool: ...
+    def fetchMore(self, _): ...
+    def can_fetch_more(self, _=None) -> bool: ...
+    def fetch_more_impl(self): ...
+    def on_items_fetched(self, items: List[T]): ...
+    def _fetch_more_cb(self, items: Optional[List[T]]): ...
+    def _async_fetch_cb(self, future): ...
+
+
+class ReaderFetchMoreMixin(Generic[T]):
     """
     The class should implement
 
@@ -323,17 +378,16 @@ class ReaderFetchMoreMixin:
     """
     no_more_item = pyqtSignal()
 
-    def canFetchMore(self, _=None):
+    def canFetchMore(self: ModelUsingReader[T], _):
         return self.can_fetch_more()
 
-    def fetchMore(self, _=None):
+    def fetchMore(self: ModelUsingReader[T], _):
         if self._is_fetching is False:
             self._is_fetching = True
             self.fetch_more_impl()
 
-    def can_fetch_more(self, _=None):
-        reader = self._reader
-
+    def can_fetch_more(self: ModelUsingReader[T], _=None):
+        reader = cast(Reader, self._reader)
         count = reader.count
         if count is not None:
             return count > self.rowCount()
@@ -342,17 +396,17 @@ class ReaderFetchMoreMixin:
         # so it is safe to return True here
         return True
 
-    def fetch_more_impl(self):
+    def fetch_more_impl(self: ModelUsingReader[T]):
         """fetch more items from reader
         """
         reader = self._reader
         step = self._fetch_more_step
 
-        if reader.is_async:
+        if isinstance(reader, AsyncReader):
             async def fetch():
                 items = []
                 count = 0
-                async for item in reader:
+                async for item in reader:  # type: ignore
                     items.append(item)
                     count += 1
                     if count == step:
@@ -361,28 +415,28 @@ class ReaderFetchMoreMixin:
             future = aio.create_task(fetch())
             future.add_done_callback(self._async_fetch_cb)
         else:
+            assert isinstance(reader, Reader)
             try:
-                items = list(itertools.islice(reader, step))
+                items = reader.read_range(self.rowCount(), step + self.rowCount())
             except ProviderIOError:
                 logger.exception('fetch more items failed')
-                self._fetch_more_cb([])
+                self._fetch_more_cb(None)
             else:
                 self._fetch_more_cb(items)
 
-    def on_items_fetched(self, items):
+    def on_items_fetched(self: ModelUsingReader[T], items: List[T]):
         begin = len(self._items)
         end = begin + len(items) - 1
         self.beginInsertRows(QModelIndex(), begin, end)
         self._items.extend(items)
         self.endInsertRows()
 
-    def _fetch_more_cb(self, items):
+    def _fetch_more_cb(self: ModelUsingReader[T], items: Optional[List[T]]):
         self._is_fetching = False
-        if items is None:
-            return
-        self.on_items_fetched(items)
+        if items is not None:
+            self.on_items_fetched(items)
 
-    def _async_fetch_cb(self, future):
+    def _async_fetch_cb(self: ModelUsingReader[T], future):
         try:
             items = future.result()
         except:  # noqa
@@ -392,63 +446,13 @@ class ReaderFetchMoreMixin:
             self._fetch_more_cb(items)
 
 
-def fetch_cover_wrapper(app):
+def fetch_cover_wrapper(app: GuiApp):
     """
     Your should only use this helper within ImgListModel and SongMiniCardListModel.
     """
     img_mgr, library = app.img_mgr, app.library
 
-    async def fetch_model_cover(model, cb):
-        # Get image unique id.
-        model_is_song = False
-        song_is_v2 = False
-        upgraded_song = None
-        if ModelType(model.meta.model_type) is ModelType.song:
-            model_is_song = True
-            if isinstance(model, BaseModel):
-                song_is_v2 = True
-                img_uid, _ = model.cache_get('album_uid')
-            else:
-                img_uid = None
-        else:
-            img_uid = reverse(model) + '/cover'
-        if img_uid is None:
-            assert model_is_song
-            try:
-                upgraded_song = await aio.run_fn(library.song_upgrade, model)
-                album = upgraded_song.album
-            except NotSupported:
-                album = None
-            if album is None:
-                cb(None)
-                return
-
-            img_uid = reverse(album) + '/cover'
-            if song_is_v2:
-                model.cache_set('album_uid', img_uid)
-
-        # Check image cache with image unique ID.
-        content = img_mgr.get_from_cache(img_uid)
-        if content is not None:
-            cb(content)
-            return
-
-        # Get image url.
-        img_url = None
-        if model_is_song and song_is_v2:
-            img_url, _ = model.cache_get('album_cover')
-        if img_url is None:
-            if model_is_song:
-                model_with_img = upgraded_song.album
-            else:
-                model_with_img = model
-            try:
-                img_url = await aio.run_fn(library.model_get_cover, model_with_img)
-            except NotSupported:
-                img_url = ''
-            if model_is_song:
-                model.cache_set('album_cover', img_url)
-
+    async def fetch_image_with_cb(img_uid, img_url, cb):
         # Fetch image by url and invoke cb.
         if img_url:
             # FIXME: sleep random second to avoid send too many request to provider
@@ -458,6 +462,78 @@ def fetch_cover_wrapper(app):
         else:
             cb(None)
 
+    async def fetch_song_pic_from_album(album, cb):
+        if album is not None:
+            await fetch_other_model_cover(album, cb)
+        else:
+            cb(None)
+
+    async def fetch_song_pic_url(model, cb):
+        """
+        The song may be a v2 brief model or a v1 model.
+        """
+        is_v2_model = isinstance(model, BaseModel)
+
+        # If the song is a v1 model, just fallback to use its album cover.
+        if not is_v2_model:
+            try:
+                upgraded_song = await aio.run_fn(library.song_upgrade, model)
+            except NotSupported:
+                cb(None)
+            else:
+                await fetch_song_pic_from_album(upgraded_song.album, cb)
+            return
+
+        # v2 song model has its own image(pic_url), check if it is in cache first.
+        cache_key = 'album_cover_uid'
+        song_img_uid = reverse(model) + '/pic_url'
+        album_img_uid, _ = model.cache_get(cache_key)
+        for img_uid in (song_img_uid, album_img_uid):
+            if img_uid:
+                content = img_mgr.get_from_cache(img_uid)
+                if content is not None:
+                    cb(content)
+                    return
+
+        # Image is not in cache.
+        try:
+            upgraded_song = await aio.run_fn(library.song_upgrade, model)
+        except (NotSupported, ResourceNotFound):
+            cb(None)
+        else:
+            # Try to fetch with pic_url first.
+            # Note that some providers may not provide pic_url for songs.
+            if upgraded_song.pic_url:
+                img_uid = reverse(model) + '/pic_url'
+                img_url = upgraded_song.pic_url
+                return await fetch_image_with_cb(img_uid, img_url, cb)
+
+            album = upgraded_song.album
+            album_img_uid = reverse(album) + '/cover'
+            model.cache_set(cache_key, album_img_uid)
+            return await fetch_song_pic_from_album(album, cb)
+
+    async def fetch_other_model_cover(model, cb):
+        img_uid = reverse(model) + '/cover'
+
+        # Check image cache with image unique ID.
+        content = img_mgr.get_from_cache(img_uid)
+        if content is not None:
+            cb(content)
+            return
+
+        try:
+            img_url = await aio.run_fn(library.model_get_cover, model)
+        except NotSupported:
+            img_url = ''
+
+        return await fetch_image_with_cb(img_uid, img_url, cb)
+
+    async def fetch_model_cover(model, cb):
+        if ModelType(model.meta.model_type) is ModelType.song:
+            return await fetch_song_pic_url(model, cb)
+        return await fetch_other_model_cover(model, cb)
+
     return fetch_model_cover
 
 
