@@ -2,10 +2,13 @@ from datetime import datetime
 
 from PyQt5.QtCore import QAbstractListModel, QModelIndex, Qt, QSize, \
     QPoint, QRect
-from PyQt5.QtGui import QPalette, QPen, QFont
-from PyQt5.QtWidgets import QStyledItemDelegate, QListView, QSizePolicy, QFrame
+from PyQt5.QtGui import QPalette, QPen, QFont, QFontMetrics
+from PyQt5.QtWidgets import QStyledItemDelegate, QListView, QSizePolicy, QFrame, \
+    QApplication, QWidget
 
 from feeluown.gui.helpers import ItemViewNoScrollMixin, Paddings, Margins
+from feeluown.library import CommentModel
+from feeluown.utils.reader import Reader
 
 
 def human_readable_number_v1(n):
@@ -15,12 +18,11 @@ def human_readable_number_v1(n):
         if n > value:
             first, second = n // value, (n % value) // (value // 10)
             return f'{first}.{second}{unit}'
-    else:
-        return str(n)
+    return str(n)
 
 
 class CommentListModel(QAbstractListModel):
-    def __init__(self, reader, parent=None):
+    def __init__(self, reader: Reader[CommentModel], parent=None):
         super().__init__(parent)
 
         self._reader = reader
@@ -44,20 +46,25 @@ class CommentListModel(QAbstractListModel):
 
 
 class CommentListDelegate(QStyledItemDelegate):
-    def __init__(self, parent):
+    def __init__(self, parent: QWidget):
         super().__init__(parent=parent)
 
         self._margin_h = 0
         self._margin_v = 10
         self._name_content_margin = 5
-        self._name_height = 15
+        self._name_height = QFontMetrics(QApplication.font()).height()
         self._parent_comment_paddings = Paddings(8, 3, 8, 3)
         self._parent_comment_margins = Margins(20, 5, 10, 5)
 
     def paint(self, painter, option, index):
+        # pylint: disable=too-many-locals,too-many-statements
+        # Explicitly set the font to the same font, so that the content
+        # height is always correct. Otherwise, the height maybe incorrect.
+        painter.setFont(QApplication.font())
+        fm = QFontMetrics(QApplication.font())
+
         painter.save()
         comment = index.data(Qt.UserRole)
-        fm = option.fontMetrics
 
         # size for render comment
         body_width = option.rect.width() - self._margin_h * 2
@@ -144,8 +151,8 @@ class CommentListDelegate(QStyledItemDelegate):
 
     def sizeHint(self, option, index):
         super_size_hint = super().sizeHint(option, index)
-        parent_width = self.parent().width()
-        fm = option.fontMetrics
+        parent_width = self.parent().width()  # type: ignore
+        fm = QFontMetrics(QApplication.font())
         comment = index.data(Qt.UserRole)
         content_width = parent_width - 2 * self._margin_h
         content_height = self._get_text_height(fm, content_width, comment.content)
@@ -162,8 +169,8 @@ class CommentListDelegate(QStyledItemDelegate):
 
     def _get_text_height(self, fm, width, text):
         return fm.boundingRect(
-            0, 0, width, 0,
-            Qt.AlignVCenter | Qt.TextWordWrap,
+            QRect(0, 0, width, 0),
+            Qt.TextWordWrap,
             text
         ).height()
 
@@ -171,8 +178,7 @@ class CommentListDelegate(QStyledItemDelegate):
 class CommentListView(ItemViewNoScrollMixin, QListView):
 
     def __init__(self, parent=None, **kwargs):
-        super().__init__(parent, **kwargs)
-        QListView.__init__(self, parent)
+        super().__init__(parent=parent, **kwargs)
 
         self._delegate = CommentListDelegate(self)
         self.setItemDelegate(self._delegate)
@@ -196,36 +202,3 @@ class CommentListView(ItemViewNoScrollMixin, QListView):
             row_count -= 1
             height += self.sizeHintForRow(row_count)
         return height
-
-
-if __name__ == '__main__':
-    import time
-    from PyQt5.QtWidgets import QApplication
-    from feeluown.utils.reader import wrap
-    from feeluown.library.models import CommentModel, BriefUserModel, BriefCommentModel
-
-    user = BriefUserModel(identifier='fuo-bot',
-                          source='fuo',
-                          name='随风而去')
-    content = ('有没有一首歌会让你很想念，有没有一首歌你会假装听不见，'
-               '听了又掉眼泪，却按不下停止健')
-    brief_comment = BriefCommentModel(identifier='ouf',
-                                      user_name='world',
-                                      content='有没有人曾告诉你')
-    comment = CommentModel(identifier='fuo',
-                           source='fuo',
-                           user=user,
-                           liked_count=1,
-                           content=content,
-                           time=int(time.time()),
-                           parent=brief_comment,)
-    comment2 = comment.copy()
-    comment2.content = 'hello world'
-
-    app = QApplication([])
-    reader = wrap([comment, comment2, comment])
-    model = CommentListModel(reader)
-    widget = CommentListView()
-    widget.setModel(model)
-    widget.show()
-    app.exec()
