@@ -1,20 +1,43 @@
+import warnings
+
 from PyQt5.QtCore import Qt, QSize, QRect
 from PyQt5.QtGui import QPainter, QBrush, QImage, QPixmap
-from PyQt5.QtWidgets import QLabel, QSizePolicy
+from PyQt5.QtWidgets import QLabel, QSizePolicy, QMenu
+
+from feeluown.gui.image import open_image
 
 
 class CoverLabel(QLabel):
     def __init__(self, parent=None, pixmap=None):
         super().__init__(parent=parent)
 
+        # There is possibility that self._img is None and self._pixmap is not None.
+        # When self._img is not None, self._pixmap can not be None.
+        self._img = None
         self._pixmap = pixmap
         self.setSizePolicy(QSizePolicy.Preferred, QSizePolicy.MinimumExpanding)
 
     def show_pixmap(self, pixmap):
+        """
+        .. versiondeprecated:: 3.8.11
+        """
+        warnings.warn('You should use show_img', DeprecationWarning)
+        self._img = None
         self._pixmap = pixmap
         self.updateGeometry()
         self.update()  # Schedule a repaint to refresh the UI ASAP.
 
+    def show_img(self, img: QImage):
+        if img.isNull():
+            return
+
+        self._img = img
+        new_img = img.scaledToWidth(self.width())
+        pixmap = QPixmap(new_img)
+        self._pixmap = pixmap
+        self.updateGeometry()
+        self.update()
+
     def paintEvent(self, e):
         """
         draw pixmap with border radius
@@ -29,12 +52,8 @@ class CoverLabel(QLabel):
         painter = QPainter(self)
         painter.setRenderHint(QPainter.Antialiasing)
         painter.setRenderHint(QPainter.SmoothPixmapTransform)
-        scaled_pixmap = self._pixmap.scaledToWidth(
-            self.width(),
-            mode=Qt.SmoothTransformation
-        )
-        size = scaled_pixmap.size()
-        brush = QBrush(scaled_pixmap)
+        size = self._pixmap.size()
+        brush = QBrush(self._pixmap)
         painter.setBrush(brush)
         painter.setPen(Qt.NoPen)
         y = (size.height() - self.height()) // 2
@@ -45,10 +64,28 @@ class CoverLabel(QLabel):
         painter.restore()
         painter.end()
 
+    def contextMenuEvent(self, e):
+        if self._img is None:
+            return
+        menu = QMenu()
+        action = menu.addAction('查看原图')
+        action.triggered.connect(lambda: open_image(self._img))
+        menu.exec(e.globalPos())
+
     def resizeEvent(self, e):
         super().resizeEvent(e)
         self.updateGeometry()
 
+        if self._img is not None:
+            # Resize pixmap.
+            img = self._img.scaledToWidth(self.width(), Qt.SmoothTransformation)
+            self._pixmap = QPixmap(img)
+        elif self._pixmap is not None:
+            self._pixmap = self._pixmap.scaledToWidth(
+                self.width(),
+                mode=Qt.SmoothTransformation
+            )
+
     def sizeHint(self):
         super_size = super().sizeHint()
         if self._pixmap is None:
@@ -74,6 +111,4 @@ class CoverLabelV2(CoverLabel):
         content = await self._app.img_mgr.get(url, cover_uid)
         img = QImage()
         img.loadFromData(content)
-        pixmap = QPixmap(img)
-        if not pixmap.isNull():
-            self.show_pixmap(pixmap)
+        self.show_img(img)
