@@ -155,6 +155,10 @@ class AlbumModel(BaseModel):
     def type_(self):  # To be compatible with AlbumModel v2.
         return self.type
 
+    @property
+    def released(self):  # To be compatible with AlbumModel v2.
+        return ''
+
 
 class LyricModel(BaseModel):
     """Lyric Model
@@ -173,7 +177,7 @@ class MvModel(BaseModel, MultiQualityMixin):
 
     class Meta:
         model_type = ModelType.video.value
-        fields = ['name', 'media', 'desc', 'cover', 'artist']
+        fields = ['name', 'media', 'desc', 'cover', 'artists', 'duration']
         support_multi_quality = False
         fields_display = ['name']
 
@@ -184,6 +188,10 @@ class MvModel(BaseModel, MultiQualityMixin):
         """
         return self.name
 
+    @title.setter
+    def title(self, value):
+        self.name = value
+
     @property
     def title_display(self):
         """
@@ -198,7 +206,8 @@ class SongModel(BaseModel, MultiQualityMixin):
     class Meta:
         model_type = ModelType.song.value
         fields = ['album', 'artists', 'lyric', 'comments', 'title', 'url',
-                  'duration', 'mv', 'media']
+                  'duration', 'mv', 'media',
+                  'disc', 'genre', 'date', 'track', 'pic_url']
         fields_display = ['title', 'artists_name', 'album_name', 'duration_ms']
 
         support_multi_quality = False
