@@ -5,7 +5,9 @@ from .mpvplayer import MpvPlayer as Player
 from .playlist import PlaylistMode, Playlist
 from .fm import FM
 from .radio import SongRadio
-from .lyric import LiveLyric, parse_lyric_text
+from .lyric import LiveLyric, parse_lyric_text, Line as LyricLine, Lyric
+from .recently_played import RecentlyPlayed
+from .delegate import PlayerPositionDelegate
 
 
 __all__ = (
@@ -18,10 +20,15 @@ __all__ = (
 
     'Player',
     'Playlist',
+    'PlayerPositionDelegate',
 
     'Metadata',
     'MetadataFields',
 
     'LiveLyric',
     'parse_lyric_text',
+    'LyricLine',
+    'Lyric',
+
+    'RecentlyPlayed',
 )
