@@ -1,31 +1,19 @@
 import locale
 import logging
 
-from feeluown.utils.utils import use_mpv_old
-from .metadata import MetadataFields, Metadata
-
-if use_mpv_old():
-    from mpv_old import (  # type: ignore
-        MPV,
-        MpvEventID,
-        MpvEventEndFile,
-        _mpv_set_property_string,
-        _mpv_set_option_string,
-        _mpv_client_api_version,
-    )
-else:
-    from mpv import (  # type: ignore
-        MPV,
-        MpvEventID,
-        MpvEventEndFile,
-        _mpv_set_property_string,
-        _mpv_set_option_string,
-        _mpv_client_api_version,
-    )
+from mpv import (  # type: ignore
+    MPV,
+    MpvEventID,
+    MpvEventEndFile,
+    _mpv_set_property_string,
+    _mpv_set_option_string,
+    _mpv_client_api_version,
+)
 
 from feeluown.utils.dispatch import Signal
 from feeluown.media import Media, VideoAudioManifest
 from .base_player import AbstractPlayer, State
+from .metadata import MetadataFields, Metadata
 
 
 logger = logging.getLogger(__name__)
@@ -155,10 +143,12 @@ class MpvPlayer(AbstractPlayer):
             start_default, end_default = 'none', 'none'
         else:
             start_default, end_default = '0%', '100%'
-        start = str(start) if start is not None else start_default
-        end = str(end) if end is not None else end_default
-        _mpv_set_option_string(self._mpv.handle, b'start', bytes(start, 'utf-8'))
-        _mpv_set_option_string(self._mpv.handle, b'end', bytes(end, 'utf-8'))
+        start_str = str(start) if start is not None else start_default
+        end_str = str(end) if end is not None else end_default
+        _mpv_set_option_string(self._mpv.handle, b'start', bytes(start_str, 'utf-8'))
+        if start is not None:
+            self.seeked.emit(start)
+        _mpv_set_option_string(self._mpv.handle, b'end', bytes(end_str, 'utf-8'))
 
     def resume(self):
         self._mpv.pause = False
@@ -218,7 +208,7 @@ class MpvPlayer(AbstractPlayer):
         self._mpv.playlist_clear()
 
     def _on_position_changed(self, position):
-        self._position = position
+        self._position = max(0, position or 0)
         self.position_changed.emit(position)
 
     def _on_duration_changed(self, duration):
